%***********Analytical inverse model for predicting fresh water discharge**
%***********Input:h--->Observed water depth (m)****************************
%                 delta--->estimated tidal damping number (-)**************
%                 eta_ave--->tidal amplitude at studied position (m)*******
%***********Output:Qf_hybrid---->predicted fresh water discharge (m^3/s)***
%                         v----->Tidal velocity amplitude (m/s)
%                         c----->wave celerity (m/s)
%                         mu---->velocity number (-)
%                         lambda--->celerity number (-)
%                         epsilon--->phase lag
%Reference: (1)Cai, H., Savenije, H. H. G., and Jiang, C.: 
%              Analytical approach for predicting fresh water discharge in an estuary based on tidal water level observations, 
%              Hydrol. Earth Syst. Sci. Discuss., 11, 7053-7087, doi:10.5194/hessd-11-7053-2014, 2014.
%Author: Huayang Cai (h.cai@tudelft.nl)
%Date:03/09/2014
%**************************************************************************
clc,clear
close all
h=9:0.1:20; % observed depth
delta=-2:0.1:0; % observed damping number
[H,Delta] = meshgrid(9:0.1:20,-2:0.1:0);
eta_ave=0.14; % observed tidal amplitude
rs=1.5; % storage width ratio
Ks=60; % Manning-Strickler friction coefficient
h0=8.74; % depth relative to the mean sea level
B0=1749; % tidally averaged width
A_ave=B0.*h; % observed cross-sectional area
a=432*1000;  % cross-sectional area convergence, here we assumed it is constant
g=9.81; % gravity acceleration
c0=sqrt(g.*h./rs); % classical wave celerity
T=12.42*3600; % tidal period
w=2*pi/T; % tidal frequency
gamma=c0./(w.*a); % estuary shape number
for j=1:length(delta)
%***********************calculating wave celerity************
lambda2=1-delta(j).*(gamma-delta(j));
lambda=sqrt(lambda2); %celerity number
c=c0./lambda; % wave celerity
%***********************calculating tidal velocity*************
mu2=1./((gamma-delta(j)).^2+1-delta(j).*(gamma-delta(j)));
mu=sqrt(mu2); %velocity number
v=mu.*rs.*eta_ave.*c0./h; % velocity
%*********************calculating phase lag********************
tan_epsilon=lambda./(gamma-delta(j));
epsilon=atan(tan_epsilon); %phase lag
epsilon=epsilon.*180./pi;
%*********************calculating river discharge******************
zeta=eta_ave./h; % the tidal amplitude-to-depth ratio
f=g./(Ks.^2.*h.^(1/3))./(1-(1.33.*zeta).^2);
Chi=rs.*g.*c0./(Ks.^2.*w.*h.^(4/3));
for i=1:length(h)
A=-4*Chi(i)*mu(i)^2*zeta(i)^2/(3-16*zeta(i)^2/3);
B=rs*delta(j)*mu(i)*zeta(i)/lambda(i)-2*mu(i)^3*Chi(i)*lambda(i)*zeta(i)/(1-16*zeta(i)^2/9)-...
    (mu(i)*gamma(i)-delta(j)*mu(i))*(sqrt(1+zeta(i))-1)/lambda(i);
C=-Chi(i)*mu(i)^2*zeta(i)^2*(8*mu(i)^2*lambda(i)^2/9+2/9)/(1-16*zeta(i)^2/9)-delta(j)+...
    mu(i)^2*gamma(i)-delta(j)*mu(i)^2;
x_hybrid(i)=(-B-sqrt(B^2-4*A*C))/(2*A);
Ur_hybrid(i)=x_hybrid(i)*v(i); % fresh water flow velocity
Qf_hybrid(j,i)=A_ave(i)*Ur_hybrid(i); % predicted fresh water discharge
end
end
%*********************plot******************
figure
[C1,h1]=contourf(H,Delta,Qf_hybrid,'LineColor','r','linestyle','--');
hold on
h_bar = colorbar;
ylabel(h_bar, '\itQ_f\rm (m^3s^{-1})')
ylabel('Damping number  \delta')
xlabel('Tidally averaged depth $\overline{h}$','interpreter','latex')

